# $Id: draw_signed.tcl,v 1.3 2005/04/25 23:56:56 aleksey Exp $

proc draw_signed {chatid from type body x} {
    global messageicon

    set chatw [chat::chat_win $chatid]

    if {[cequal [info commands ::ssj::signed:input] ""]} {
        return
    }

    foreach xe $x {
        jlib::wrapper:splitxml $xe tag vars isempty chdata children

# in case the sender didn't check the exit code from gpg...
        if {([cequal $chdata ""]) \
                || (![cequal [jlib::wrapper:getattr $vars xmlns] \
                             jabber:x:signed])} {
            continue
        }

        for {set i 0} {[winfo exists $chatw.signed$i]} {incr i} {}
	set connid [chat::get_connid $chatid]
        catch {
            $chatw window create end \
                  -window [ssj::signed:Label $chatw.signed$i \
                              [ssj::signed:input $connid $from $chdata $body \
                                  "Message body"]]
        }
    }
}

hook::add draw_message_hook [namespace current]::draw_signed 6
